/*	$NetBSD: msg_253.c,v 1.4 2022/06/17 18:54:53 rillig Exp $	*/
# 3 "msg_253.c"

// Test for message: unterminated character constant [253]

/* expect+3: error: unterminated character constant [253] */
/* expect+2: error: syntax error '' [249] */
'
