/*	$NetBSD: platform_ldbl96.c,v 1.2 2021/09/26 14:28:22 rillig Exp $	*/
# 3 "platform_ldbl96.c"

/*
 * Test features that only apply to platforms that have 96-bit long double.
 */

/* lint1-extra-flags: -c -h -a -p -b -r -z */
/* lint1-only-if: ldbl-96 */

// TODO: Add some code that passes.
// TODO: Add some code that fails.

/* expect+1: warning: empty translation unit [272] */
